\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{rutgersletter}[2007/05/18 v1.00 New Style Letterhead]
%%% The following variables are the ones which are used to
%%% populate the letterhead text.  Changing them is simple --
%%% put them in a config file and then load it in.  We provide 
%%% the config for LCSR and DCS already
\newcommand{\@ifIsEmptyString}[1]{\edef\@es@token{#1}\ifx\@empty\@es@token}

\newcommand{\linefy}[1]{%
\@ifIsEmptyString{#1}{}\else{#1}\\\fi%
}%

\def\@ru@deptinfo{}
\def\@ru@persinfo{}

\newcommand{\setPersonalContent}[1]{%
 \def\@ru@persinfo{#1}%
}%

\newcommand{\setDepartmentalContent}[1]{%
 \def\@ru@deptinfo{#1}%
}%

\def\@@usepers{}

\input dept.cfg

\DeclareOption{personal}{%
        \def\@@usepers{true}%
}
\DeclareOption{personalized}{%
        \def\@@usepers{true}%
}

%  option sunj uses the logo with sunj, and removes that line from address
\newif\ifsunj\sunjfalse
\def\doputsunj#1{\nextline{Rutgers, the State University of New Jersey}{#1}}
\def\usesunj{}    % Use rutgers logo with state U on NJ
\DeclareOption{sunj}{
\sunjtrue
\def\doputsunj#1{}
}

\newif\ifbw\bwfalse
\DeclareOption{bw}{
\bwtrue
}

\newif\ifpage\pagetrue
\DeclareOption{nopage}{\pagefalse}

\newif\iftoname\tonamefalse
\DeclareOption{toname}{\tonametrue}

%  option rjust right justifies the text in the rightmost info block
\newif\ifrjst\rjstfalse
\DeclareOption{rjust}{
\rjsttrue
}


%%% Give everything else to the letter class . . .
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions

\RequirePackage{berasans}
\RequirePackage{palatino}
\RequirePackage{ifthen}
\RequirePackage{graphicx}
\LoadClass{letter}

\ifx\@empty\@@cfgfile\else\input \@@cfgfile\fi
\ifx\@empty\@@usepers\else\input pers.cfg\fi

% Set up the page dimensions to mimic the Word ones as much as possible
\setlength\voffset{0in}
\setlength\hoffset{0in}
\setlength\marginparwidth{0in}
\setlength\marginparsep{0in}
\setlength\marginparpush{0in}
\setlength\evensidemargin{.25in}
\setlength\oddsidemargin{.25in}
\setlength\headsep{1in}
\setlength\topmargin{-0.5in}
\setlength\headheight{0in}
\setlength\textwidth{6in}

% And define our own widths and offsets for convenience   (line 86)
\newlength{\@ru@logowidth}  %width of the box holding the logo/signature
                                % also called
\newlength{\@ru@deptwidth}  %width of the box holding the dept address
                                % also called
\newlength{\@ru@perswidth}  %width of the box with the email/web addresses
                                % also called
\newlength{\@ru@offsetlogo}    %kludge offset to get text baselines okay
\newlength{\@ru@offsethead}    %horizontal offset of header
% temporary catalogue of other defined lengths:    line 95
% \oruologow    = 
% \oruologobw   = 
% \oruologoh    = 
% \oruologobh   = 
% \newdeptw     = \@ru@deptwidth
% \newdepth     = 
% \newpersw     = \@ru@perswidth
% \newpersh     =
% \topheight    = max of \newdepth and \newpersh
% \exspace      = \@ex@space
% \@ex@space
% \oruoaddrw    = \the\wd\@ru@dept
% \oruoaddrh    = \the\ht\@ru@dept + \the\dp\@ru@dept
% \oruocontactw = \the\wd\@ru@pers
% \oruocontacth = \the\ht\@ru@pers + \the\dp\@ru@pers
% \@ru@letterwidth = full width of first page letterhead


% line 114
\setlength\@ru@logowidth{2.25in}     %I changed from 3.05in
% \setlength\@ru@offsetlogo{-22.1pt}   % needs adjustment if sunj? bottom 
\setlength\@ru@offsetlogo{-3.0pt}   % top of U to top of box ?
\setlength\@ru@offsethead{-31.2pt}   % KEB hsd 34pt

% heading font: 7pt Vera Sans.  Using a 8.4pt basline skip on the assumption
% that fontsize * 1.2 is a good baseline skip
\newcommand{\@ru@headerfont}{%
  \fontencoding{T1}%
  \fontfamily{fvs}%
  \fontseries{m}%
  \fontsize{7}{8.4}%   Joel thinks baslineskip should be raised to 10 or 11
  \selectfont%
}
\newsavebox{\@ru@letterhead}
\newsavebox{\@ru@letterfoot}
% line 130
\newsavebox{\@ru@logo}     %this is logo, possibly with sunj
\newsavebox{\@ru@logob}    %this is Rutgers logo without sunj
\newsavebox{\@ru@dept}     %this is the middle block, with department address
\newsavebox{\@ru@pers}     %this is the right block, with individual info

%  \ifsunj\addtolength{\@ru@offsetlogo}{-8.775pt}\fi%
\sbox{\@ru@logo}{\begin{minipage}[b]{\@ru@logowidth}%
\vspace*{\@ru@offsetlogo}%
\ifbw\ifsunj \includegraphics[width=1.5truein]{rulogostBW}%
\else\includegraphics[width=1.5truein]{rulogoBW}\fi%
\else
\ifsunj \includegraphics[width=1.5truein]{rulogostC}%
\else\includegraphics[width=1.5truein]{rulogoC}\fi%
\fi
\end{minipage}%
}
% line 145
% more diagnostics
\newsavebox{\oruologo}
\newsavebox{\oruologob}
\newsavebox{\oruodept}
\newsavebox{\oruopers}

\sbox{\@ru@logob}{\begin{minipage}[b]{\@ru@logowidth}%  this is for page 3,5,
\ifbw\includegraphics[width=1.5truein]{rulogoBW}%
\else\includegraphics[width=1.5truein]{rulogoC}\fi
\vspace{\@ru@offsetlogo}%
\end{minipage}%
}
% line 158


%temporary stuff for debugging only:
\newlength{\oruologow}
\newlength{\oruologobw}
\newlength{\oruologoh}
\newlength{\oruologobh}
% line 166
\setlength{\oruologow}{\the\wd\@ru@logo}
\setlength{\oruologobw}{\the\wd\@ru@logob}
\setlength{\oruologoh}{\the\ht\@ru@logo}
\addtolength{\oruologoh}{\the\dp\@ru@logo}
\setlength{\oruologobh}{\the\ht\@ru@logob}
\addtolength{\oruologobh}{\the\dp\@ru@logob}
%end of temp
% line 174
% Now to determine the natural sizes of dept and pers blocks
% my method did not get the height right, so lets eliminate that
\newbox\testbox
\newdimen\boxwd
\dimen\boxwd=0pt
\def\nextline#1#2{\global\setbox0=\hbox{#1}%
\ifdim\boxwd<\wd0 \global\boxwd=\wd0\fi%
}%  line 182
% 
%
\setbox\testbox=\vbox{\hbox{This is just junk}%
\@ru@headerfont\@ru@deptinfo}%
% more temporary diagnostic stuff
\newlength\newdeptw
\newlength\newdepth
\newlength\newpersw
\newlength\newpersh
%end temp diag
\setlength\newdeptw\boxwd
% line 194
\boxwd=0pt
%
%
\setbox\testbox=\vbox{\hbox{This is just junk}%
\@ru@headerfont\@ru@persinfo}
\setlength\newpersw\boxwd
% line 201
\def\nextline#1#2{#1\\[#2]}
\savebox{\@ru@dept}{\parbox{\newdeptw}{\@ru@headerfont\@ru@deptinfo}}%
\setlength\newdepth{\the\ht\@ru@dept}
\addtolength\newdepth{\the\dp\@ru@dept}
\savebox{\@ru@pers}{\parbox{\newpersw}{\@ru@headerfont\@ru@persinfo}}%
\setlength\newpersh{\the\ht\@ru@pers}
\addtolength\newpersh{\the\dp\@ru@pers}
% line 209
\newlength\topheight
\setlength{\topheight}{\newdepth}
\ifdim\topheight < \newpersh
  \setlength{\topheight}{\newpersh}
\fi

% \def\nextline#1#2{\ifrjst\hfill\fi{#1}\vskip #2 plus 2 pt}
%    \newbox\@ru@pers
%temporary stuff for debugging only:   line 218
\newlength\exspace
\newlength\oruoaddrw
\newlength\oruoaddrh
\newlength\oruocontactw
\newlength\oruocontacth
% end of temp

\newlength{\@ru@letterwidth}%  KEB had = textwidth, seemed wrong to me
\setlength{\@ru@letterwidth}{-2\@ru@offsethead}
\addtolength{\@ru@letterwidth}{\textwidth}%
% line 229
%Calculate the extra space before dept block
\newlength\@ex@space
\setlength\@ex@space\@ru@letterwidth
\addtolength\@ex@space{-\the\wd\@ru@logob}
\addtolength\@ex@space{-\newdeptw}
\addtolength\@ex@space{-\newpersw}
\addtolength\@ex@space{-0.25in}%  for space between dept and pers

%temporary stuff for debugging only:
\setlength\exspace\@ex@space
% end of temp

\def\@ru@logohead{%
 \hbox to \@ru@letterwidth {%
  \usebox{\@ru@logob}\hfill%   Joel changed to b
    \iftoname\toname\hfill\fi
    \ifpage Page \thepage\fi}%
}

% line 247
\sbox{\@ru@letterfoot}{\parbox[t]{\textwidth}{}}

\renewcommand{\ps@firstpage}{%
        \renewcommand{\@oddhead}{\hspace{\@ru@offsethead}\@ru@letterhead}%
        \renewcommand{\@oddfoot}{\usebox{\@ru@letterfoot}}%
}
% line 254
\if@twoside
    \renewcommand{\ps@headings}{%
        % blank footers
        \let\@oddfoot\@empty%
        \let\@evenfoot\@empty%
        % blank even headers  4/9/07 Joel inserted toname and page
        \renewcommand{\@evenhead}{\iftoname\toname\fi\hfill%
          \ifpage Page \thepage\fi}
        \renewcommand{\@oddhead}{\hspace{\@ru@offsethead}\@ru@logohead}%
    }%
\else
    \renewcommand{\ps@headings}{%
        \renewcommand{\@oddfoot}{}%
        \renewcommand{\@evenfoot}{}%\@empty
        \renewcommand{\@oddhead}{\hspace{\@ru@offsethead}\@ru@logohead}%
        \renewcommand{\@evenhead}{\hspace{\@ru@offsethead}\@ru@logohead}%
    }%
\fi

\pagestyle{headings}
\def\nextline#1#2{{\noindent\ifrjst\hfill\fi\mbox{#1}\vskip #2 plus 2pt}}
%    \def\nextline#1#2{{{#1}\\[#2]}}
\renewcommand\opening[1]{
% line 275
% \savebox{\@ru@pers}[\newpersw]{%
\setbox\@ru@pers\hbox to \newpersw{%
    \@ru@headerfont%
    \parskip=0pt%
    \hsize=\newpersw%
    \vbox to \topheight{\@ru@persinfo\vskip-\lastskip}
}
%  \savebox{\@ru@dept}[\newdeptw]{%
\setbox\@ru@dept\hbox to\newdeptw{%
    \ifx\@empty\@@usepers\else\rjstfalse\fi%
    \@ru@headerfont%
    \parskip=0pt%
    \hsize=\newdeptw%
    \vbox to \topheight{\@ru@deptinfo\vskip-\lastskip}
}
% line 285
% diagnostics
\setlength\oruoaddrw{\the\wd\@ru@dept}
\setlength\oruoaddrh{\the\ht\@ru@dept}
\addtolength{\oruoaddrh}{\the\dp\@ru@dept}
\setlength\oruocontactw{\the\wd\@ru@pers}
\setlength\oruocontacth{\the\ht\@ru@pers}
\addtolength{\oruocontacth}{\the\dp\@ru@pers}
% end diag

\newsavebox\deptaddrbox
\newsavebox\persaddrbox
\savebox\deptaddrbox[\newdeptw]{\usebox{\@ru@dept}}
\savebox\persaddrbox[\newpersw]{\usebox{\@ru@pers}}

\def\@ru@letterhead{%
 \hbox to \@ru@letterwidth {%
   \vbox to \topheight{\hsize=\@ru@logowidth%
   \usebox{\@ru@logo}\vfill}\hskip\@ex@space    % mod 3/31 late
   \vbox to \topheight {\hsize=\the\wd\@ru@dept%
     \usebox{\@ru@dept}%
   }%
   \hskip 0.25in%
   \vbox to \topheight {\hsize=\the\wd\@ru@pers%
     \usebox{\@ru@pers}%
   }%
  }%
}
\thispagestyle{firstpage}%
%% the next lines are ugly:  we force a space then add 1inch vertical space
%% this will only work well with the LCSR address
\hfill \@date\hfill  \\%
\\%
\toname \\%
\toaddress%
\par
#1
}

\def\@texttop{}

\renewcommand{\closing}[1]{\par\nobreak\vspace{\parskip}%
  \stopbreaks\noindent\hspace*{\longindentation}%
  \parbox{\indentedwidth}{\raggedright
     \ignorespaces #1\\[6\medskipamount]%
     \ifx\@empty\fromsig \fromname \else \fromsig \fi \strut}%
  \par}
 
