%%
%% This is file `rumemo.cls' written by Dave Steiner (steiner@cs.rutgers.edu)
%%
%% rewritten from scratch for latex2e but based on  rumemo.sty 20 Jul 89 
%%  by Dave Steiner (steiner@topaz.rutgers.edu) which was 
%% based on memo.sty 16 Apr 87  (Capt Mark Roth, ENG, 53576, mroth@afit.arpa)

%%
%% This class supports the Rutgers letterhead.
%% Usage: \documentclass[<dept>]{rumemo} where <dept> is one of the 
%%  supported departments or "memo".
%%
%% it uses the following info
%%   \from{..}  printed in the FROM block
%%   \to{..}    printed in the TO block
%%   \subject{..}  printed in the SUBJECT block
%%   \date{..}  if specified used in the date area, else the current
%%        date is used
%%   \signature{..} printed after memo as your signature block
%%   \cc{..}, \encl{..}, and \ps also work.
%%   \begin{memo} follow this with your text
%%   \end{memo}   follow your text with this
%% You also need to use \begin{document} and \end{document}
%% You can have multiple line from, to, subject and signature blocks, just
%% separate the lines with \\


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{rumemo}
              [1997/04/16 v2.2
               Rutgers Letterhead memo class]
\RequirePackage{epsf}

%% Deal with department information via an option.
\newcommand{\@dept}{0} % 0 instead of -1 so that we default to the memo version
\DeclareOption{memo}{\renewcommand{\@dept}{0}}
\DeclareOption{dcs}{\renewcommand{\@dept}{1}}
\DeclareOption{math}{\renewcommand{\@dept}{2}} 
\DeclareOption{lcsr}{\renewcommand{\@dept}{3}}
\DeclareOption{lcsrcomp}{\renewcommand{\@dept}{4}}
\DeclareOption{dece}{\renewcommand{\@dept}{5}}
\DeclareOption{caip}{\renewcommand{\@dept}{6}}
\DeclareOption{dpa}{\renewcommand{\@dept}{7}}
\DeclareOption{njin}{\renewcommand{\@dept}{8}}
\DeclareOption{rutcor}{\renewcommand{\@dept}{9}}
\DeclareOption{rucsNBCS}{\renewcommand{\@dept}{10}}
%\DeclareOption{rucsUS}{\renewcommand{\@dept}{11}}
\DeclareOption{rucsTELE}{\renewcommand{\@dept}{12}}
\DeclareOption{rucsTD}{\renewcommand{\@dept}{12}}
\DeclareOption{rucsADMIN}{\renewcommand{\@dept}{13}}
\DeclareOption{rucsACS}{\renewcommand{\@dept}{13}}
\DeclareOption{rucsLCSR}{\renewcommand{\@dept}{14}}
\DeclareOption{rucsNEWARK}{\renewcommand{\@dept}{15}}
\DeclareOption{rucsCAMDEN}{\renewcommand{\@dept}{16}}
\DeclareOption{ruccs}{\renewcommand{\@dept}{17}}
\DeclareOption{dmae}{\renewcommand{\@dept}{18}}
\DeclareOption{mathchair}{\renewcommand{\@dept}{19}}
\DeclareOption{mathgrad}{\renewcommand{\@dept}{20}}
\DeclareOption{mathcenter}{\renewcommand{\@dept}{21}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions
\LoadClass{letter}

\setlength\textwidth{6.5in}
\setlength\textheight{8.5in}
\setlength\evensidemargin{0\p@}
\setlength\oddsidemargin {0\p@}
\setlength\marginparwidth{0\p@}
\setlength\marginparsep  {0\p@}
\setlength\topmargin     {0\p@}

\newdimen\skip@space
%% redefine \opening to get letterhead 
\newbox\SubjBox \setbox\SubjBox=\hbox{SUBJECT: }
\newdimen\SubjBoxd \SubjBoxd=\wd\SubjBox
\newdimen\skip@space

\renewcommand{\opening}{
  \let\@texttop=\relax
  \thispagestyle{empty}%
  \letterhead
  \font\little=phvr at 9 truept		% Helvetica
  \ifx\@empty\lhaddr\else
   \vskip\skip@space
   {\def\\{\hss\egroup\baselineskip=10truept\@@line\bgroup\hss}%
   \little\centerline{\lhaddr}}\fi
  \vglue 0.5 truein\relax
  \hbox to \hsize{\hfill \@date}\par
  \bigskip
  \hbox to \hsize{\hbox to \SubjBoxd{TO: \hfil}%
   \begin{tabular}[t]{l}\ignorespaces\toaddress
   \end{tabular} \hfill}\par
  \medskip
  \hbox to \hsize{\hbox to \SubjBoxd{FROM: \hfil}%
    \begin{tabular}[t]{l}\ignorespaces\fromaddress 
    \end{tabular}\hfill} \par
  \medskip
  \hbox to \hsize{\hbox to \SubjBoxd{SUBJECT: \hfil}%
    \begin{tabular}[t]{l}\ignorespaces\subj
    \end{tabular}\hfill} \par
  \vspace{2\parskip}%
  \par\nobreak}

\renewcommand{\closing}{%
 \par\nobreak\vspace{6\parskip}%
 \stopbreaks
 \noindent
 \ifx\@empty\fromsig 
 \else \fromsig
 \fi\strut
 \par}

\def\subject#1{\def\subj{#1}}
\def\subj{}
\long\def\from#1{\def\fromaddress{#1}}
\def\fromaddress{}
\def\to#1{\def\toaddress{#1}}
\def\toaddress{}
%% Add \lhaddress{} to personalize letterhead information
\long\def\lhaddress#1{\def\lhaddr{#1}}
\def\lhaddr{}

\renewcommand{\cc}[1]{\par\medskip\noindent
  \parbox[t]{\textwidth}{\@hangfrom{\reset@font\rm \ccname: }%
                         \ignorespaces #1\strut}\par}
\renewcommand{\encl}[1]{\par\medskip\noindent
  \parbox[t]{\textwidth}{\@hangfrom{\reset@font\rm \enclname: }%
                         \ignorespaces #1\strut}\par}

\newenvironment{memo}%
 {\newpage
  \if@twoside \ifodd\c@page
              \else\thispagestyle{empty} \hbox{}\newpage\fi
  \fi
  \c@page\@ne
  \interlinepenalty=200 \opening}
 {\closing\@@par\pagebreak\@@par}

\if@twoside
  \def\ps@headings{%
      \let\@oddfoot\@empty\let\@evenfoot\@empty
      \def\@oddhead{\slshape \ignorespaces
		    \begin{tabular}[t]{l}\ignorespaces\subj
		    \end{tabular} 
                    \hfil \@date
                    \hfil \pagename{} \thepage}%
      \let\@evenhead\@oddhead
\else
  \def\ps@headings{%
      \let\@oddfoot\@empty
      \def\@oddhead{\slshape \ignorespaces
		    \begin{tabular}[t]{l}\ignorespaces\subj
		    \end{tabular} 
                    \hfil \@date
                    \hfil \pagename{} \thepage}}
\fi

\def\ps@letempty{%
  \def\@oddfoot{\raisebox {-45\p@}[\z@]{\hbox to \textwidth{\hspace*{100\p@}}}}
  \let\@oddhead\@empty
  \let\@evenfoot\@empty\let\@evenhead\@empty}

\pagestyle{headings}

%

\newcommand{\letterhead}{%
 \hoffset-10truept %.12truein
  {\parskip=0pt
   \baselineskip=-1000pt\lineskip=0pt\lineskiplimit=\maxdimen
   \hbox{}\vskip-102truept
   \vbox to 87truept{
      \ifcase\@dept
	\@memolines		% No. 0
      \or
	\@dcslines		% No. 1
      \or
	\@mathlines		% No. 2
      \or
	\@lcsrlines		% No. 3
      \or
	\@lcsrcomplines		% No. 4
      \or
	\@decelines		% No. 5
      \or
	\@caiplines		% No. 6
      \or
	\@dpalines		% No. 7
      \or
	\@njinlines		% No. 8
      \or
	\@rutcorlines		% No. 9
      \or
	\@rucsNBCSlines		% No. 10
      \or
	\@rucsUSlines		% No. 11
      \or
	\@rucsTDlines		% No. 12
      \or
	\@rucsACSlines		% No. 13
      \or
	\@rucsLCSRlines		% No. 14
      \or
	\@rucsNEWARKlines	% No. 15
      \or
	\@rucsCAMDENlines	% No. 16
      \or
	\@ruccslines		% No. 17
      \or
	\@dmaelines		% No. 18
      \or
	\@mathchairlines	% No. 19
      \or
	\@mathgradlines		% No. 20
      \or
	\@mathcenterlines	% No. 21
      \else
	\ClassError{rumemo}{%
	  You must give an option to documentclass specifying\MessageBreak
	  the department to use}
         {%
	  You must use \protect\documentclass[<dept>]{rumemo} where <dept>
	  is a\MessageBreak supported department.
         }
      \fi \vss
      \typeout{}
      \typeout{NOTE!! You must run dvips manually on this document before}
      \typeout{you print it. The letterhead will look best if printed on}
      \typeout{something other than a LaserWriterI (eg., LaserWriter Plus).}
      \typeout{}
      \vskip.92truein
      \vskip 0pt plus .00006fil\relax}}}

\newcommand{\@memolines}{\global\skip@space=-19truept	%1 line of text
   \special{header=/usr/local/lib/tex/rulogo/memologo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@dcslines}{\global\skip@space=-9truept	%2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/dcslogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@mathlines}{\global\skip@space=1truept	%3 lines of text
   \special{header=/usr/local/lib/tex/rulogo/mathlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@mathchairlines}{\global\skip@space=1truept      %3 lines of text
   \special{header=/usr/local/lib/tex/rulogo/mathchairlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@mathgradlines}{\global\skip@space=1truept	%3 lines of text
   \special{header=/usr/local/lib/tex/rulogo/mathgradlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@mathcenterlines}{\global\skip@space=21truept    %5 lines of text
   \special{header=/usr/local/lib/tex/rulogo/mathcenterlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@lcsrlines}{\global\skip@space=-9truept	%2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/lcsrlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@lcsrcomplines}{\global\skip@space=1truept	%3 lines of text
   \special{header=/usr/local/lib/tex/rulogo/lcsrcomplogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@decelines}{\global\skip@space=-9truept	%2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/decelogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@dmaelines}{\global\skip@space=-9truept	%2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/dmaelogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@caiplines}{\global\skip@space=-9truept	%2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/caiplogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@dpalines}{\global\skip@space=-9truept	%2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/dpalogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@njinlines}{\global\skip@space=-9truept	%2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/njinlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@rutcorlines}{\global\skip@space=1truept	%3 lines of text
   \special{header=/usr/local/lib/tex/rulogo/rutcorlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@rucsNBCSlines}{\global\skip@space=-9truept  %2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/rucs-nbcslogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

% No longer valid!
\newcommand{\@rucsUSlines}{\global\skip@space=-9truept	%2 lines of text
   }

\newcommand{\@rucsTDlines}{\global\skip@space=-9truept     %2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/rucs-telelogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@rucsACSlines}{\global\skip@space=-9truept    %2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/rucs-adminlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@rucsLCSRlines}{\global\skip@space=-9truept     %2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/rucs-lcsrlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@rucsNEWARKlines}{\global\skip@space=-9truept   %2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/rucs-newarklogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@rucsCAMDENlines}{\global\skip@space=-9truept   %2 lines of text
   \special{header=/usr/local/lib/tex/rulogo/rucs-camdenlogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\newcommand{\@ruccslines}{\global\skip@space=1truept	%3 lines of text
   \special{header=/usr/local/lib/tex/rulogo/ruccslogo.pro}
   \centerline{\epsffile{/usr/local/lib/tex/rulogo/rlogo.ps}}}

\endinput
%% 
%% End of file `rumemo.cls'.
